@@ -1,12 +1,9 @@
 import os
-import pathlib
 import validators
-import yaml
 
 from dateutil import parser
 from datetime import datetime
 from typing import Dict, Optional
-from pathlib import Path
 
 from .constants import (
     API_KEY_CONFIG_KEY,
@@ -18,6 +15,7 @@ from .constants import (
 from .exceptions import AuthException, URLException
 from .interfaces import MQLInterface, BackendInterface
 from .models import User, Organization, ModelKey, UserState
+from .config_handler import ConfigHandler
 
 
 class TransformAuth:  # noqa: D
@@ -36,7 +34,7 @@ class TransformAuth:  # noqa: D
         self.__api_key: Optional[str] = None
         self._use_async = use_async
         self.target_org_id = target_org_id
-        self.config = ConfigHandler(override_config)
+        self.config = ConfigHandler("config.yml", override_config)
 
         # Overrides
         if api_key is not None:
@@ -48,7 +46,7 @@ class TransformAuth:  # noqa: D
     def api_key(self) -> Optional[str]:
         """Pull API key from config file by default, also supporting a fallback environment variable TRANSFORM_API_KEY."""
         if self.__api_key is None:
-            config_api_key = self.config._get_config_value(API_KEY_CONFIG_KEY)
+            config_api_key = self.config.get_config_value(API_KEY_CONFIG_KEY)
             return config_api_key if config_api_key else os.getenv("TRANSFORM_API_KEY")
         return self.__api_key
 
@@ -64,15 +62,15 @@ class TransformAuth:  # noqa: D
         self.__api_key = api_key
 
         # Remove bearer token auth if exists
-        self.config._remove_config_value(BEARER_TOKEN_CONFIG_KEY)
-        self.config._remove_config_value(BEARER_TOKEN_EXPIRES_AT_CONFIG_KEY)
+        self.config.remove_config_value(BEARER_TOKEN_CONFIG_KEY)
+        self.config.remove_config_value(BEARER_TOKEN_EXPIRES_AT_CONFIG_KEY)
 
-        self.config._set_config_value(API_KEY_CONFIG_KEY, api_key)
+        self.config.set_config_value(API_KEY_CONFIG_KEY, api_key)
 
     @property
     def bearer_token(self) -> Optional[str]:
         """Get bearer token from config, if exists."""
-        token = self.config._get_config_value(BEARER_TOKEN_CONFIG_KEY)
+        token = self.config.get_config_value(BEARER_TOKEN_CONFIG_KEY)
         if (
             token is not None
             and self.bearer_token_expires_at is not None
@@ -84,17 +82,17 @@ class TransformAuth:  # noqa: D
 
     @bearer_token.setter
     def bearer_token(self, bearer_token: str) -> None:  # noqa: D
-        self.config._set_config_value(BEARER_TOKEN_CONFIG_KEY, bearer_token)
-        self.config._remove_config_value(API_KEY_CONFIG_KEY)
+        self.config.set_config_value(BEARER_TOKEN_CONFIG_KEY, bearer_token)
+        self.config.remove_config_value(API_KEY_CONFIG_KEY)
 
     @property
     def bearer_token_expires_at(self) -> Optional[str]:
         """Time that current bearer token will expire, if exists."""
-        return self.config._get_config_value(BEARER_TOKEN_EXPIRES_AT_CONFIG_KEY)
+        return self.config.get_config_value(BEARER_TOKEN_EXPIRES_AT_CONFIG_KEY)
 
     @bearer_token_expires_at.setter
     def bearer_token_expires_at(self, bearer_token_expires_at: str) -> None:  # noqa: D
-        self.config._set_config_value(BEARER_TOKEN_EXPIRES_AT_CONFIG_KEY, bearer_token_expires_at)
+        self.config.set_config_value(BEARER_TOKEN_EXPIRES_AT_CONFIG_KEY, bearer_token_expires_at)
 
     @property
     def auth_header(self) -> Dict[str, str]:
@@ -116,7 +114,7 @@ class TransformAuth:  # noqa: D
     def backend_client(self) -> BackendInterface:
         """Returns backend client"""
         overrides = {}
-        backend_override = self.config._get_config_value(BACKEND_OVERRIDE_CONFIG_KEY)
+        backend_override = self.config.get_config_value(BACKEND_OVERRIDE_CONFIG_KEY)
         if backend_override:
             overrides["rest_api_url"] = backend_override
         return BackendInterface(auth_header=self.auth_header, use_async=self._use_async, **overrides)
@@ -165,15 +163,15 @@ class TransformAuth:  # noqa: D
 
         Overrideable via passing MQL server url at instantiation process for users who need to redirect using a local proxy.
         """
-        return self.config._get_config_value(MQL_OVERRIDE_CONFIG_KEY) if self.config.override_config else None
+        return self.config.get_config_value(MQL_OVERRIDE_CONFIG_KEY) if self.config.override_config else None
 
     @mql_server_url_config_override.setter
     def mql_server_url_config_override(self, mql_server_url: str) -> None:  # noqa: D
         if not mql_server_url:
-            self.config._remove_config_value(MQL_OVERRIDE_CONFIG_KEY)
+            self.config.remove_config_value(MQL_OVERRIDE_CONFIG_KEY)
         elif validators.url(mql_server_url, public=False):
             self.__mql_server_url = mql_server_url
-            self.config._set_config_value(MQL_OVERRIDE_CONFIG_KEY, mql_server_url)
+            self.config.set_config_value(MQL_OVERRIDE_CONFIG_KEY, mql_server_url)
         else:
             raise URLException(mql_server_url)
 
@@ -184,71 +182,3 @@ class TransformAuth:  # noqa: D
                 query_server_url=self.mql_server_url, auth_header=self.auth_header, use_async=self._use_async
             )
         return self.__mql_client
-
-
-class ConfigHandler:
-    """Class for handling interactions with config.yml"""
-
-    def __init__(self, override_config: bool = True) -> None:  # noqa: D
-        # Check if the proper directory exists, if not create it
-        if not os.path.exists(self.config_dir):
-            cofig_dir = pathlib.Path(self.config_dir)
-            cofig_dir.mkdir(parents=True)
-        self.override_config = override_config
-
-    @property
-    def config_dir(self) -> str:
-        """Retrieve Transform config_dir from $TFD_CONFIG_DIR, default config dir is ~/.transform"""
-        config_dir_env = os.getenv("TFD_CONFIG_DIR")
-
-        return config_dir_env if config_dir_env else f"{str(Path.home())}/.transform"
-
-    @property
-    def config_file_path(self) -> str:
-        """Config file can be found at <config_dir>/config.yml"""
-        return os.path.join(self.config_dir, "config.yml")
-
-    def _get_config_value(self, key: str) -> Optional[str]:
-        try:
-            config_file = open(self.config_file_path, "r")
-        except FileNotFoundError:
-            return None
-
-        config = yaml.load(config_file, Loader=yaml.Loader)
-        if config and key in config and config[key]:
-            return config[key]
-
-        return None
-
-    def _set_config_value(self, key: str, value: str) -> None:
-        # If the caller passed a falsey value, assume they'd like to remove the key
-        if not self.override_config:
-            return  # Don't override config if flagged
-        if not value:
-            return self._remove_config_value(key)
-
-        configs: Dict[str, str] = {}
-        if os.path.exists(self.config_file_path):
-            with open(self.config_file_path) as f:
-                configs = yaml.load(f, Loader=yaml.SafeLoader) or {}
-
-        configs[key] = value
-
-        with open(self.config_file_path, "w") as f:
-            yaml.dump(configs, f)
-
-    def _remove_config_value(self, key: str) -> None:
-        if not self.override_config:
-            return  # Don't override config if flagged
-        configs: Dict[str, str] = {}
-        if os.path.exists(self.config_file_path):
-            with open(self.config_file_path) as f:
-                configs = yaml.load(f, Loader=yaml.SafeLoader) or {}
-
-        if key not in configs:
-            return
-
-        del configs[key]
-
-        with open(self.config_file_path, "w") as f:
-            yaml.dump(configs, f)
