@@ -3,6 +3,7 @@ import time
 import webbrowser
 import textwrap
 import requests
+from pathlib import Path
 
 from datetime import datetime, timedelta
 from halo import Halo
@@ -14,9 +15,14 @@ from ..constants import (
     API_KEY_CONFIG_KEY,
     BEARER_TOKEN_CONFIG_KEY,
     PINNED_MODEL_ID_CONFIG_KEY,
+    PREV_CONFIG_DIR_MODIFIED,
+    PREV_CONFIG_DIR_PATH,
+    PREV_MODEL_ID,
 )
 from ..models import ModelKey, UserState
 from ..mql import MQLClient
+from ..config_handler import ConfigHandler
+from ..utils import directory_last_edited
 
 
 class CLIContext(TransformAuth):
@@ -29,6 +35,7 @@ class CLIContext(TransformAuth):
         self.__just_authenticated = False
         super().__init__()
         self.mql = MQLClient(use_async=True)
+        self.cli_state = ConfigHandler(".cli.yml")
 
     @property
     def is_authenticated(self) -> bool:  # noqa: D
@@ -72,14 +79,14 @@ class CLIContext(TransformAuth):
 
     def remove_api_key_and_prompt_browser_login(self) -> None:
         """Remove API key from config and prompt browser login. Used when MFA is newly required for an org."""
-        if self.config._get_config_value(API_KEY_CONFIG_KEY) is not None:
-            self.config._remove_config_value(API_KEY_CONFIG_KEY)
+        if self.config.get_config_value(API_KEY_CONFIG_KEY) is not None:
+            self.config.remove_config_value(API_KEY_CONFIG_KEY)
         self.prompt_auth0_login()
 
     @property
     def bearer_token(self) -> Optional[str]:
         """Get bearer token from config, if exists."""
-        token = self.config._get_config_value(BEARER_TOKEN_CONFIG_KEY)
+        token = self.config.get_config_value(BEARER_TOKEN_CONFIG_KEY)
         if (
             token is not None
             and self.bearer_token_expires_at is not None
@@ -93,8 +100,8 @@ class CLIContext(TransformAuth):
 
     @bearer_token.setter
     def bearer_token(self, bearer_token: str) -> None:  # noqa: D
-        self.config._set_config_value(BEARER_TOKEN_CONFIG_KEY, bearer_token)
-        self.config._remove_config_value(API_KEY_CONFIG_KEY)
+        self.config.set_config_value(BEARER_TOKEN_CONFIG_KEY, bearer_token)
+        self.config.remove_config_value(API_KEY_CONFIG_KEY)
         self.identify()
         self.__just_authenticated = True
         if self.bearer_token_expires_at is not None:
@@ -222,21 +229,21 @@ class CLIContext(TransformAuth):
     @property
     def pinned_model_id(self) -> Optional[int]:
         """Config override for the org's current model key. Primarily used for development"""
-        out = self.config._get_config_value(PINNED_MODEL_ID_CONFIG_KEY)
+        out = self.config.get_config_value(PINNED_MODEL_ID_CONFIG_KEY)
         return int(out) if out else None
 
     @pinned_model_id.setter
     def pinned_model_id(self, model_id: int) -> None:  # noqa: D
         if not model_id:
-            self.config._remove_config_value(PINNED_MODEL_ID_CONFIG_KEY)
+            self.config.remove_config_value(PINNED_MODEL_ID_CONFIG_KEY)
 
         # fetch model row to ensure it's valid
         self.mql.get_model_key(model_id)
-        self.config._set_config_value(PINNED_MODEL_ID_CONFIG_KEY, str(model_id))
+        self.config.set_config_value(PINNED_MODEL_ID_CONFIG_KEY, str(model_id))
 
     def unpin_model(self) -> None:  # noqa: D
         if self.pinned_model_id:
-            self.config._remove_config_value(PINNED_MODEL_ID_CONFIG_KEY)
+            self.config.remove_config_value(PINNED_MODEL_ID_CONFIG_KEY)
 
     @property
     def current_model(self) -> Optional[ModelKey]:  # noqa: D
@@ -250,9 +257,36 @@ class CLIContext(TransformAuth):
         * Otherwise, we default to None so that the query server can resolve the proper model key for the org.
         """
         if config_dir:
+            last_config_path = self.cli_state.get_config_value(PREV_CONFIG_DIR_PATH)
+            last_config_modified = self.cli_state.get_config_value(PREV_CONFIG_DIR_MODIFIED)
+            last_config_model_id = self.cli_state.get_config_value(PREV_MODEL_ID)
+
+            current_config_path = str(Path(config_dir).resolve())
+            current_config_modified = directory_last_edited(config_dir)
+
+            if (
+                last_config_path is not None
+                and last_config_modified is not None
+                and last_config_model_id is not None
+                and current_config_modified is not None
+                and current_config_path == last_config_path
+                and last_config_modified == str(current_config_modified)
+            ):
+                model_key = self.mql.get_model_key(int(last_config_model_id))
+                click.echo(f"Using local model id {last_config_model_id}, created {model_key.created_at}")
+                return model_key
+
             spinner = Halo(text="Parsing and uploading local configs…", spinner="dots")
             spinner.start()
             model_key = self.mql.commit_configs(config_dir)
+
+            self.cli_state.set_config_value(PREV_MODEL_ID, str(model_key.id))
+            self.cli_state.set_config_value(PREV_CONFIG_DIR_PATH, current_config_path)
+            if current_config_modified:
+                self.cli_state.set_config_value(PREV_CONFIG_DIR_MODIFIED, str(current_config_modified))
+            else:
+                self.cli_state.remove_config_value(PREV_CONFIG_DIR_MODIFIED)
+
             spinner.succeed("🌱 Successfully parsed local configs")
             return model_key
 
