@@ -3,7 +3,7 @@ import ast
 import logging
 import click
 
-from datetime import datetime
+from dateutil.parser import parse
 from functools import wraps
 from typing import Any, Callable, List, Optional
 
@@ -148,6 +148,7 @@ def query_options(function: Callable) -> Callable:
         callback=lambda ctx, param, value: PercentChange(value) if value is not None else None,
     )(function)
 
+    function = start_end_time_options(function)
     return function
 
 
@@ -203,17 +204,16 @@ def no_active_mql_servers(org_name: str) -> None:
     )
 
 
-def valid_datetime(dt_str: str) -> bool:
-    """Returns true if string is valid iso8601 timestamp, false otherwise"""
+def validate_date_string(datetime_str: Optional[str]) -> Optional[str]:
+    """Validates the date string, raises exception if invalid."""
+    if datetime_str is None:
+        return None
+
     try:
-        datetime.fromisoformat(dt_str)
+        parse(datetime_str)
     except Exception:
-        try:
-            datetime.fromisoformat(dt_str.replace("Z", "+00:00"))
-        except Exception:
-            return False
-        return True
-    return True
+        raise click.BadParameter("must be valid iso8601 timestamp (eg., '2020-01-04')")
+    return datetime_str
 
 
 def enable_debug_log_file() -> None:  # noqa: D
@@ -247,5 +247,26 @@ def exception_handler(func: Callable[..., Any]) -> Callable[..., Any]:  # type:
             click.echo(f"\nERROR: {str(e)}")
             if debug:
                 raise e
+            exit(1)
 
     return wrapper
+
+
+def start_end_time_options(function: Callable) -> Callable:
+    """Options for start_time and end_time."""
+    function = click.option(
+        "--start-time",
+        type=str,
+        default=None,
+        help="Optional iso8601 timestamp to constraint the start time of the data (inclusive) (eg., '2020-01-04')",
+        callback=lambda ctx, param, value: validate_date_string(value),
+    )(function)
+
+    function = click.option(
+        "--end-time",
+        type=str,
+        default=None,
+        help="Optional iso8601 timestamp to constraint the end time of the data (inclusive) (eg., '2020-01-04')",
+        callback=lambda ctx, param, value: validate_date_string(value),
+    )(function)
+    return function
