@@ -7,6 +7,7 @@ import textwrap
 import pandas as pd
 from halo import Halo
 from typing import Dict, List, Optional
+from datetime import datetime
 
 from log_symbols import LogSymbols
 from packaging.version import parse
@@ -23,11 +24,11 @@ from .cli_utils import (
     async_options,
     no_active_mql_servers,
     validate_query_args,
-    valid_datetime,
     enable_debug_log_file,
     get_query_logs_url_for_id,
     query_observability_options,
     exception_handler,
+    start_end_time_options,
 )
 from ..models import (
     CacheMode,
@@ -38,6 +39,7 @@ from ..models import (
     TimeGranularity,
 )
 from .. import PACKAGE_NAME, __version__
+from ..constants import CLI_UPDATE_LAST_CHECKED, MAX_TIME_BEFORE_UPDATE
 
 pass_config = click.make_pass_decorator(CLIContext, ensure=True)
 
@@ -55,22 +57,34 @@ def cli(config: CLIContext, verbose: bool, skip_confirm: bool, debug_log_file: b
 
     if debug_log_file:
         enable_debug_log_file()
+    check_for_update = False
+    last_updated = config.cli_state.get_config_value(CLI_UPDATE_LAST_CHECKED)
+    if last_updated is None or last_updated == "":
+        check_for_update = True
+    else:
+        try:
+            check_for_update = (datetime.now().timestamp() - float(last_updated)) > MAX_TIME_BEFORE_UPDATE
+        except ValueError:
+            pass
+    if check_for_update:
+        checker = UpdateChecker()
+        result = checker.check(PACKAGE_NAME, __version__)
+        config.cli_state.set_config_value(CLI_UPDATE_LAST_CHECKED, str(datetime.now().timestamp()))
+        # result is None when an update was not found or a failure occurred
+        if result:
+            # Note: As the CLI and API stabilize, we can be a little less aggressive about forcing upgrade
+            # For now, we should do so to minimize the likelihood of out of date CLIs causing unexpected behavior
+            click.secho(
+                "Warning: A new version of the MQL CLI is available.",
+                bold=True,
+                fg="red",
+            )
 
-    checker = UpdateChecker()
-    result = checker.check(PACKAGE_NAME, __version__)
-    # result is None when an update was not found or a failure occured
-    if result:
-        # Note: As the CLI and API stabilize, we can be a little less aggressive about forcing upgrade
-        # For now, we should do so to minimize the likelihood of out of date CLIs causing unexpected behavior
-        click.secho(
-            "Warning: A new version of the MQL CLI is available.",
-            bold=True,
-            fg="red",
-        )
-
-        click.echo(
-            f"Please update to version {result.available_version}, released {result.release_date} by running:\n\t$ pip install --upgrade {PACKAGE_NAME}",
-        )
+            click.echo(
+                f"Please update to version {result.available_version}, released {result.release_date} by running:\n\t$ pip install --upgrade {PACKAGE_NAME}",
+            )
+        else:
+            click.echo(f"Using the latest version of {PACKAGE_NAME} ({__version__}).")
 
 
 @cli.command()
@@ -148,13 +162,14 @@ def setup(
         exit()
 
     # If the user doesn't yet have auth creds, wants to override existing cred, or token is expired
-    if not config.just_authenticated and (
-        not config.is_authenticated
-        or click.confirm(
-            f"We've found existing credentials for {config.user.user_name} within the {config.org.name} organization.\nWould you like to provide new credentials, thus resetting the existing credentials?"
-        )
-    ):
-        config.prompt_authentication()
+    if not config.just_authenticated:
+        if not config.is_authenticated or (
+            not config.just_authenticated
+            and click.confirm(
+                f"We've found existing credentials for {config.user.user_name} within the {config.org.name} organization.\nWould you like to provide new credentials, thus resetting the existing credentials?"
+            )
+        ):
+            config.prompt_authentication()
 
     # If the user has an existing MQL server override, let them know and ask if they want it removed
     if config.mql_server_url_config_override and click.confirm(
@@ -313,6 +328,8 @@ def query(
     limit: Optional[str] = None,
     cache_mode: Optional[CacheMode] = None,
     config_dir: Optional[str] = None,
+    start_time: Optional[str] = None,
+    end_time: Optional[str] = None,
     as_table: Optional[str] = None,
     csv: Optional[click.utils.LazyFile] = None,
     explain: bool = False,
@@ -344,6 +361,8 @@ def query(
         cache_mode=cache_mode.value if cache_mode else None,
         as_table=as_table,
         allow_dynamic_cache=allow_dynamic_cache,
+        start_time=start_time,
+        end_time=end_time,
     ).query_id
 
     spinner.succeed(f"Query initialized: {query_id}")
@@ -400,18 +419,7 @@ def query(
     type=str,
     help="Name of materialization to drop",
 )
-@click.option(
-    "--start-time",
-    required=False,
-    type=str,
-    help="iso8601 timestamp to drop from",
-)
-@click.option(
-    "--end-time",
-    required=False,
-    type=str,
-    help="iso8601 timestamp to drop to",
-)
+@start_end_time_options
 @async_options
 @query_observability_options
 @pass_config
@@ -434,11 +442,6 @@ def drop_materialization(
     # Purposefully pulling this out before the spinner
     model_key = config.resolve_query_model_key(config_dir)
 
-    if start_time and not valid_datetime(start_time):
-        click.ClickException("start_time must be valid iso8601 timestamp")
-    if end_time and not valid_datetime(end_time):
-        click.ClickException("end_time must be valid iso8601 timestamp")
-
     if not config.skip_confirm and start_time is None:
         if not click.confirm(
             "You haven't provided a start_time. This means we will drop the materialization from the beginning of time."
@@ -490,18 +493,7 @@ def drop_materialization(
     type=str,
     help="Name of materialization to materialize",
 )
-@click.option(
-    "--start-time",
-    required=False,
-    type=str,
-    help="iso8601 timestamp to materialize from",
-)
-@click.option(
-    "--end-time",
-    required=False,
-    type=str,
-    help="iso8601 timestamp to materialize to",
-)
+@start_end_time_options
 @click.option(
     "--output-table",
     required=False,
@@ -533,11 +525,6 @@ def materialize(
     # Purposefully pulling this out before the spinner
     model_key = config.resolve_query_model_key(config_dir)
 
-    if start_time and not valid_datetime(start_time):
-        click.ClickException("start_time must be valid iso8601 timestamp")
-    if end_time and not valid_datetime(end_time):
-        click.ClickException("end_time must be valid iso8601 timestamp")
-
     if not config.skip_confirm and start_time is None:
         if not click.confirm(
             "You haven't provided a start_time. This means we will materialize from the beginning of time. This may be expensive. Are you sure you want to continue?"
@@ -751,7 +738,9 @@ def list_dimensions(config: CLIContext, metric_names: Optional[str] = None) -> N
 
     model_key = config.resolve_query_model_key()
     dimensions = sorted(
-        config.mql.list_dimensions(model_key.id if model_key else None, metric_names_input).values(),
+        config.mql.list_dimensions(
+            metric_names=metric_names_input, model_key_id=model_key.id if model_key else None
+        ).values(),
         key=lambda d: d.name,
     )
     if not dimensions:
@@ -854,10 +843,7 @@ def _data_warehouse_validations_runner(config: CLIContext, model_id: Optional[in
     issues: List[str] = []
     issues += _run_dw_validations(config=config, type=DWValidationType.DATA_SOURCE, model_id=model_id)
     issues += _run_dw_validations(config=config, type=DWValidationType.DIMENSION, model_id=model_id)
-
-    # TODO: Even though we are about to have feature flagging on the mql_query server, only bring
-    # this back once metric dw validations don't cause priming
-    # issues += _run_dw_validations(config=config, type=DWValidationType.METRIC, model_id=model_id)
+    issues += _run_dw_validations(config=config, type=DWValidationType.METRIC, model_id=model_id)
 
     print(colored("\n".join(issues), "red"))
     return len(issues) == 0
