@@ -10,10 +10,8 @@ import textwrap
 
 from typing import List, Dict, Optional, Tuple, Any
 
-from transform.vendor.gql import Client, gql
-from transform.vendor.gql.transport.aiohttp import AIOHTTPTransport
-from transform.vendor.gql.transport.requests import RequestsHTTPTransport
-from transform.vendor.gql.client import DocumentNode
+from gql import Client, gql
+from gql.transport.requests import RequestsHTTPTransport
 
 from transform_tools.validate import (
     validate_configs as tt_validate_configs,
@@ -66,21 +64,21 @@ class BaseInterface:
     """
 
     def __init__(self, auth_header: Dict[str, str], rest_api_url: str, use_async: bool = False) -> None:  # noqa: D
+        # FIXME: use_async is available, but since we had to downgrade to GQL 2, it makes
+        # no difference to the underlying transport. We should probably come back to this
+        # later and find out an elegant solution to async execution.
+
         self.rest_api_url = rest_api_url
         self.auth_header = auth_header
 
-        gql_transport = (
-            AIOHTTPTransport(url=self.graphql_api_url, headers=self.auth_header)
-            if use_async
-            else RequestsHTTPTransport(url=self.graphql_api_url, retries=2, headers=self.auth_header)
-        )
         self.gql_client = Client(
-            transport=gql_transport,  # type: ignore
+            transport=RequestsHTTPTransport(
+                url=self.graphql_api_url, retries=2, headers=self.auth_header, timeout=90
+            ),  # type: ignore
             fetch_schema_from_transport=False,
-            execute_timeout=90,  # 1.5 minute
         )
 
-    def execute(self, query: DocumentNode, verbose: bool = False, variable_values: Dict[str, Any] = None) -> Dict[str, Any]:  # type: ignore[misc]
+    def execute(self, query: Any, verbose: bool = False, variable_values: Dict[str, Any] = None) -> Dict[str, Any]:  # type: ignore[misc]
         """Error handling for GQL Clients"""
         start_time = time.time()
         try:
@@ -468,6 +466,8 @@ class MQLInterface(BaseInterface):  # noqa: D
         time_series: bool = True,
         result_format: Optional[str] = None,
         allow_dynamic_cache: bool = True,
+        start_time: Optional[str] = None,
+        end_time: Optional[str] = None,
     ) -> Dict[str, Any]:
         return {
             "modelKey": {
@@ -491,6 +491,8 @@ class MQLInterface(BaseInterface):  # noqa: D
             "timeSeries": time_series,
             "resultFormat": result_format,
             "allowDynamicCache": allow_dynamic_cache,
+            "startTime": start_time,
+            "endTime": end_time,
         }
 
     def drop_materialization(  # noqa: D
@@ -869,6 +871,8 @@ class MQLInterface(BaseInterface):  # noqa: D
         as_table: Optional[str] = None,
         allow_dynamic_cache: bool = True,
         result_format: Optional[str] = None,
+        start_time: Optional[str] = None,
+        end_time: Optional[str] = None,
     ) -> str:
         """Implements CreateMqlQuery mutation in MQL/GQL"""
 
@@ -891,6 +895,8 @@ class MQLInterface(BaseInterface):  # noqa: D
                 $resultFormat: ResultFormat,
                 $pctChange: PercentChange,
                 $allowDynamicCache: Boolean,
+                $startTime: String,
+                $endTime: String,
             ) {
                 createMqlQuery(
                     input: {
@@ -908,6 +914,8 @@ class MQLInterface(BaseInterface):  # noqa: D
                         resultFormat: $resultFormat,
                         pctChange: $pctChange,
                         allowDynamicCache: $allowDynamicCache
+                        startTime: $startTime,
+                        endTime: $endTime
                     }
                 ) {
                     id
@@ -931,6 +939,8 @@ class MQLInterface(BaseInterface):  # noqa: D
             time_series=time_series,
             result_format=result_format,
             allow_dynamic_cache=allow_dynamic_cache,
+            start_time=start_time,
+            end_time=end_time,
         )
 
         return self.execute(query, variable_values=params)["createMqlQuery"]["id"]
