@@ -55,6 +55,8 @@ class MQLClient:
         as_table: Optional[str] = None,
         allow_dynamic_cache: bool = True,
         result_format: Optional[str] = None,
+        start_time: Optional[str] = None,
+        end_time: Optional[str] = None,
     ) -> MqlQueryStatusResp:
         """Builds a query in MQL and returns a MqlQueryStatusResp detailing the results."""
         model_key = self.get_model_key(model_key_id) if model_key_id else None
@@ -72,6 +74,8 @@ class MQLClient:
             as_table,
             allow_dynamic_cache,
             result_format,
+            start_time,
+            end_time,
         )
         return self.context.mql_client.get_query_status(query_id)
 
@@ -95,6 +99,8 @@ class MQLClient:
         as_table: Optional[str] = None,
         allow_dynamic_cache: bool = True,
         timeout: Optional[int] = None,
+        start_time: Optional[str] = None,
+        end_time: Optional[str] = None,
     ) -> pd.DataFrame:
         """Builds a query in MQL and returns pandas dataframe of queried result.
 
@@ -116,6 +122,8 @@ class MQLClient:
             CacheMode(cache_mode) if cache_mode else None,
             as_table,
             allow_dynamic_cache,
+            start_time,
+            end_time,
         )
         return self.get_query_dataframe(query_id, timeout)
 
@@ -134,6 +142,8 @@ class MQLClient:
         as_table: Optional[str] = None,
         allow_dynamic_cache: bool = True,
         timeout: Optional[int] = None,
+        start_time: Optional[str] = None,
+        end_time: Optional[str] = None,
     ) -> MqlQueryStatusResp:
         """Builds a query in MQL and returns a MqlQueryStatusResp.
 
@@ -153,6 +163,8 @@ class MQLClient:
             CacheMode(cache_mode) if cache_mode else None,
             as_table,
             allow_dynamic_cache,
+            start_time,
+            end_time,
         )
         try:
             result = self.get_query_dataframe(query_id, timeout)
